#!/usr/bin/env python3

import sys
import os
import getopt
import argparse
from . import recolor
from . import resize
from . import frosted
import sys

# https://docs.python.org/3/library/argparse.html#sub-commands


def main():
    parser = argparse.ArgumentParser(
        prog="ezpp",
        usage="ezpp [-h] subcommand{recolor,resize} ...",
        description="Example: ezpp recolor -f my.png -c #00ff00"
    )
    subparsers = parser.add_subparsers(
        title='subcommands',
        dest='subcommands',
        description='ezpp [subcommand] [options]',
        help='subcommand using:ezpp [subcommand] -h')
    frosted.create_cmd_parser(subparsers)
    recolor.create_cmd_parser(subparsers)
    resize.create_cmd_parser(subparsers)

    if len(sys.argv) < 2:
        parser.print_help()
        exit(2)

    args = parser.parse_args()
    args.on_args_parsed(args)


if __name__ == "__main__":
    main()



#!/usr/bin/env python3

import tkinter as tk
import tkinter.ttk as ttk
from PIL import Image, ImageTk, ImageFilter


class Application(tk.Frame):
    def __init__(self, master=None, filename=None):
        super().__init__(master)
        self.master = master
        self.filename = filename
        self.create_widgets()

    def create_widgets_images(self, root):
        self.image = Image.open(self.filename)
        self.imageTK = ImageTk.PhotoImage(self.image)
        self.imgLabel = ttk.Label(root, image=self.imageTK, text='origin')
        self.imgLabel.pack(side="left", fill='x')

        self.imgFrosted = ttk.Label(root, text='forested', compound='image')
        self.imgFrosted.pack(side="right", fill='x')

    def create_widgets_fileinfos(self, root):
        self.fileLabel = ttk.Label(root, text="file:xxx")
        self.fileLabel.pack(side="bottom", anchor='nw')

        self.fileOutputLabel = ttk.Label(root, text="file output :xxx")
        self.fileOutputLabel.pack(side="bottom", anchor='sw')

    def create_widgets_controls(self, root):
        self.blur = 10
        self.mode = 3
        self.sblur = ttk.Scale(root, orient='horizontal',
                               length=600, from_=1.0, to=100.0, command=self.update_blur)
        # pack(side='top', ipadx=10, ipady=10, anchor='center')
        self.lbBlur = ttk.Label(root, text='Blur:')
        self.lbMode = ttk.Label(root, text='Mode:')
        self.rbModeNone = ttk.Radiobutton(
            root, text='None', value=0, command=self.update_modeNone)
        self.mode = tk.StringVar()
        self.rbMode3 = ttk.Radiobutton(
            root, text='3', value=3, command=self.update_mode3)

        self.rbMode5 = ttk.Radiobutton(
            root, text='5', value=5, command=self.update_mode5)

        self.lbBlur.grid(row=0, column=0, ipadx=10, ipady=10)
        self.sblur.grid(row=0, column=1, columnspan=3, ipadx=10, ipady=10)
        self.lbMode.grid(row=1, column=0)
        self.rbModeNone.grid(row=1, column=1)
        self.rbMode3.grid(row=1, column=2)
        self.rbMode5.grid(row=1, column=3)

    def update_mode5(self):
        self.mode = 5
        self.frosted()

    def update_mode3(self):
        self.mode = 3
        self.frosted()

    def update_modeNone(self):
        self.mode = None
        self.frosted()

    def update_blur(self, value):
        self.blur = round(float(value))
        self.frosted()

    def create_widgets(self):

        self.fileinfos_frame = ttk.Frame()
        self.create_widgets_fileinfos(self.fileinfos_frame)
        self.fileinfos_frame.pack(side='top', fill='x')

        self.controls_frame = ttk.Frame()
        self.create_widgets_controls(self.controls_frame)
        self.controls_frame.pack(side='top', fill='x')

        self.images_frame = ttk.Frame()
        self.create_widgets_images(self.images_frame)
        self.images_frame.pack(side='bottom', fill='x')

    def frosted(self):
        print(f"frosted b:{self.blur} m:{self.mode}")
        self.imageFrosted = self.image.filter(
            ImageFilter.GaussianBlur(self.blur))
        if self.mode:
            self.imageFrosted = self.imageFrosted.filter(
                ImageFilter.ModeFilter(self.mode))
        self.imageTKFrosted = ImageTk.PhotoImage(self.imageFrosted)
        self.imgFrosted.config(image=self.imageTKFrosted)


def frosted_editer(filename):
    root = tk.Tk()
    ttk.Style().configure(
        "TButton",
        padding=16,
        relief="flat",
        background="#ccc"
    )
    ttk.Style().configure(
        "TFrame",
        padding=16,
        relief="flat",
        background="#99ff99"
    )
    ttk.Style().configure(
        "TLabel",
        padding=16,
        relief="flat",
        background="#eef"
    )
    app = Application(master=root, filename=filename)
    app.master.title(filename)
    app.master.geometry("1024x768")
    app.mainloop()



__all__ = (
    "__title__", "__summary__", "__uri__", "__version__", "__author__",
    "__email__", "__license__", "__copyright__",
)

__title__ = "ezpp"
__summary__ = "Easy Pic Process"
__uri__ = "https://github.com/caojianfeng/ezpp"

__version__ = "1.0.0"

__author__ = "JeffreyCao"
__email__ = "je255reycao@stufft.io"

__license__ = "MIT Licence"
__copyright__ = "Copyright 2019 JeffreyCao"



#!/usr/bin/env python3
from PIL import Image, ImageDraw, ImageFont, ImageEnhance, ImageFilter, ImageColor
import argparse
import os
import re
import colorsys

using_color = "The color in hex value in formate of #RRGGBB  or #RGB. For example :#00ff00 or #0f0 make a  green version of your pic"

is_color_re = re.compile(r'^#?([0-9a-fA-f]{3}|[0-9a-fA-f]{6})$')
color3_re = re.compile(
    r'^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$'
)
color6_re = re.compile(
    r'^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$'
)


def create_cmd_parser(subparsers):
    parser_recolor = subparsers.add_parser(
        'recolor', help='recolor a pic')
    parser_recolor.add_argument("--file",
                                "-f",
                                help="the file to be recolor")
    parser_recolor.add_argument("--color",
                                "-c",
                                help=using_color)
    # parser_recolor.add_argument("--outfile",
    #                             "-o",
    #                             help="Optional the output file")
    parser_recolor.set_defaults(on_args_parsed=_on_args_parsed)


def repeat2(str_tobe_repeat):
    if len(str_tobe_repeat) > 1:
        return str_tobe_repeat
    return str_tobe_repeat+str_tobe_repeat


def _on_args_parsed(args):
    params = vars(args)
    filename = params['file']
    color = params['color']

    if not is_color_re.match(color):
        print(using_color)
        exit(2)

    color_re = color6_re if len(color) > 4 else color3_re
    color_m = color_re.match(color)
    r = repeat2(color_m.group(1))
    g = repeat2(color_m.group(2))
    b = repeat2(color_m.group(3))
    recolor(filename, r, g, b)


def recolor(filename, red, green, blue):
    bar_filename, ext = os.path.splitext(filename)
    # src_h, src_s, src_v = colorsys.rgb_to_hsv(0, 152/255, 1)
    dst_h, dst_s, dst_v = colorsys.rgb_to_hsv(
        int(red, base=16)/255, int(green, base=16)/255, int(blue, base=16)/255)
    # print(dst_h, dst_s, dst_v)
    color = f"{red}{green}{blue}"
    new_filename = f"{bar_filename}_0x{color}{ext}"
    print(f"{filename} + #{color} -> {new_filename}")
    img = Image.open(filename).convert('RGBA')
    width = img.width
    height = img.height
    px = img.load()

    img_new = Image.new('RGBA', (width, height))
    px_new = img_new.load()

    for y in range(0, height):
        for x in range(0, width):
            r, g, b, a = px[x, y]
            h, s, v = colorsys.rgb_to_hsv(r/255, g/255, b/255)
            rn, gn, bn = colorsys.hsv_to_rgb(dst_h, s, v)
            px_new[x, y] = (int(255*rn), int(255*gn), int(255*bn), a)

    img_new.save(new_filename, 'PNG')



#!/usr/bin/env python3

import argparse
import re
import os
import shutil
from PIL import Image, ImageDraw, ImageFont, ImageEnhance, ImageFilter, ImageColor
# readlines, writelines, readstr, readjson, list_by_ext
from ezutils.files import readjson

re_wh = re.compile(r'^([0-9]+)x([0-9]+)$')
re_size = re.compile(r'^([0-9]+)$')
re_percent = re.compile(r'^([0-9]+)%$')

size_using = """
(1) WIDTH AND HEIGHT For example :300x400 ;
(2) SIZE OF SQUARE For example : 128 means a 128x128 size ;
(3) PERCENT For example : 25%% ;
"""


def brother_path(filename): return os.path.join(
    os.path.dirname(__file__), filename)


def create_cmd_parser(subparsers):
    parser_resize = subparsers.add_parser(
        'resize', help='resize a pic',
    )
    parser_resize.add_argument("-f",
                               "--file",
                               help="The file to be resize")
    parser_resize.add_argument("-o",
                               "--outfile",
                               help="The output file resized")
    resize_group = parser_resize.add_mutually_exclusive_group()
    resize_group.add_argument("-s",
                              "--size",
                              help=size_using)
    resize_group.add_argument("-a",
                              "--app",
                              action='store_true',
                              help="Resize app icons for android and ios")

    parser_resize.set_defaults(on_args_parsed=_on_args_parsed)


def _on_args_parsed(args):
    params = vars(args)
    app = params['app']
    infile = params['file']
    outfile = params['outfile']
    size = params['size']

    if app:
        _on_app_parsed(infile, outfile)
    else:
        _on_size_parsed(infile, outfile, size)


def _on_app_parsed(infile, outfile):

    img = Image.open(os.path.abspath(infile))
    (origin_w, origin_h) = img.size
    if origin_h != 1024 or origin_w != 1024:
        print("Input file should be 1024x1024 picture !")
        return

    cfg_dir = brother_path('resize_cfg')
    cfg_file = f"{cfg_dir}/app_icon.json"
    resize_cfgs, copy_cfgs = _get_icon_sizes_from_cfg(cfg_file)

    output_dir = outfile or f"{infile}.out"

    index = 0
    count = len(resize_cfgs)
    for cfg in resize_cfgs:
        filename = cfg.get("filename")
        size = cfg.get("size")
        print(f"[{index+1}/{count}]--------- RESIZE ----------")
        _resize(infile, f"{output_dir}/{filename}", origin_w, origin_h,
                size, size, img)
        index += 1

    index = 0
    count = len(copy_cfgs)
    for cfg in copy_cfgs:
        print(f"[{index+1}/{count}]--------- COPY ----------")
        _copy(os.path.abspath(f"{cfg_dir}/{cfg.get('from')}"),
              os.path.abspath(f"{output_dir}/{cfg.get('to')}"))
        index += 1


def _get_icon_sizes_from_cfg(cfg_file):
    cfgs = readjson(cfg_file)
    # print(cfgs)

    icons_cfg = cfgs['icons']
    copies_cfg = cfgs['copies']
    return icons_cfg, copies_cfg


def _on_size_parsed(infile, outfile, size):

    (width, height) = _parse_wh_from_size(size)
    new_width = width
    new_height = height

    img = Image.open(os.path.abspath(infile))
    (origin_w, origin_h) = img.size

    if width < 1 and height < 1:

        new_width = int(origin_w * width)
        new_height = int(origin_h * height)

    _resize(infile, outfile, origin_w, origin_h, new_width, new_height, img)


def _resize(infile, outfile, origin_w, origin_h, new_width, new_height, img):
    bar_filename, ext = os.path.splitext(infile)
    filename_new = outfile if outfile else f"{bar_filename}_{new_width}x{new_height}{ext}"

    print(f"resize: ({origin_w}, {origin_h})->({new_width}, {new_height})")
    print(f"from:   {os.path.abspath(infile)}")
    print(f"to:     {os.path.abspath(filename_new)}")

    out_dir, filename = os.path.split(filename_new)
    if not os.path.exists(out_dir):
        os.makedirs(out_dir)

    img_tobe_scale = img.resize(
        (int(new_width), int(new_height)), Image.ANTIALIAS)
    img_tobe_scale.save(os.path.abspath(filename_new), 'PNG')


def _copy(src_file, dst_file):
    print(f"from:    {src_file}")
    print(f"copy to: {dst_file}")
    out_dir, filename = os.path.split(dst_file)
    if not os.path.exists(out_dir):
        os.makedirs(out_dir)
    shutil.copy(src_file, dst_file)


def _parse_wh_from_size(size):
    m_wh = re_wh.match(size)
    if m_wh:
        width = int(m_wh.group(1))
        height = int(m_wh.group(2))
        return (width, height)

    m_size = re_size.match(size)
    if m_size:
        width = int(m_size.group(1))
        height = width
        return (width, height)

    m_percent = re_percent.match(size)
    if m_percent:
        width = float(m_percent.group(1))/float(100)
        height = width
        return (width, height)
    else:
        print(size_using)
        exit(2)



#!/usr/bin/env python3
from PIL import Image, ImageDraw, ImageFont, ImageEnhance, ImageFilter
import argparse
import os
import re


def create_cmd_parser(subparsers):
    parser_recolor = subparsers.add_parser(
        'frosted', help='frosted glass on a pic')
    parser_recolor.add_argument("-f",
                                "--file",
                                help="the file to be frosted")
    parser_recolor.add_argument("-s",
                                "--size",
                                help="size of frosted range, default 10, recommonded [3,20]")
    parser_recolor.set_defaults(on_args_parsed=_on_args_parsed)


def repeat2(str_tobe_repeat):
    if len(str_tobe_repeat) > 1:
        return str_tobe_repeat
    return str_tobe_repeat+str_tobe_repeat


def _on_args_parsed(args):
    params = vars(args)
    filename = params['file']
    size = int(params['size'])
    mode = 5
    if size:
        if size > 5:
            mode = 5
        elif size > 3:
            mode = 3
        else:
            mode = 0

        frosted(filename, size, mode)
    else:
        frosted(filename)


def frosted(filename, blurSize=10, mode=5):
    bar_filename, ext = os.path.splitext(filename)
    new_filename = f"{bar_filename}_frosted{ext}"
    print(f"{filename} frosted -> {new_filename}")
    img = Image.open(filename)
    img = img.filter(ImageFilter.GaussianBlur(blurSize))

    if mode > 0:
        img = img.filter(ImageFilter.ModeFilter(mode))

    img.show()
    img.save(new_filename, 'PNG')
